# craigslist-reposter

Simple automation of craigslist listing renewal and reposting:

- Selenium to access craigslist.com, IMAPClient package to authenticate login
- User information is imported from environment variables
- Pings an optional Discord webhook when reposts are completed
